package com.yonge.cooleshow.biz.dal.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yonge.cooleshow.biz.dal.entity.TenantStaff;
import com.yonge.cooleshow.biz.dal.mapper.TenantStaffMapper;
import com.yonge.cooleshow.biz.dal.service.TenantStaffService;
import com.yonge.cooleshow.biz.dal.wrapper.TenantStaffWrapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

/**
 * 机构员工表
 * 2023-07-21 17:32:49
 */
@Slf4j
@Service
public class TenantStaffServiceImpl extends ServiceImpl<TenantStaffMapper, TenantStaff> implements TenantStaffService {

	/**
     * 查询详情
     * @param id 详情ID
     * @return TenantStaff
     */
	@Override
    public TenantStaff detail(Long id) {
        
        return baseMapper.selectById(id);
    }
    
    /**
     * 分页查询
     * @param page IPage<TenantStaff>
     * @param query TenantStaffWrapper.TenantStaffQuery
     * @return IPage<TenantStaff>
     */
    @Override
    public IPage<TenantStaff> selectPage(IPage<TenantStaff> page, TenantStaffWrapper.TenantStaffQuery query) {
        
        return page.setRecords(baseMapper.selectPage(page, query));
    }
	
    /**
     * 添加
     * @param tenantStaff TenantStaffWrapper.TenantStaff
     * @return Boolean
     */
    @Override
    public Boolean add(TenantStaffWrapper.TenantStaff tenantStaff) {    	
        
        return this.save(JSON.parseObject(tenantStaff.jsonString(), TenantStaff.class));
    }

    /**
     * 更新
     * @param tenantStaff TenantStaffWrapper.TenantStaff
     * @return Boolean
     */
    @Override
    public Boolean update(TenantStaffWrapper.TenantStaff tenantStaff){

        return this.updateById(JSON.parseObject(tenantStaff.jsonString(), TenantStaff.class));       
    }

    @Override
    public TenantStaff getByPhone(String phone) {
        return baseMapper.getByPhone(phone);

    }

    /**
     * 根据用户ID获取员工信息
     *
     * @param userId 用户Id
     * @return TenantStaff
     */
    @Override
    public TenantStaff getByUserId(Long userId) {

        return lambdaQuery().eq(TenantStaff::getUserId, userId).last("LIMIT 1").one();
    }
}